Geraldo Reports Engine
Description: Geraldo is a reports engine for Python or Django applications. It uses the power of ReportLab and PIL to generate reports with page header and footer, child bands, report begin and summary bands, agreggation and graphic elements, etc.
Keywords: Python, Django, reports, framework, open-source, engine

# Be welcome, this is Geraldo, a Python reports engine!

### Get Geraldo

You have four ways to get Geraldo.

#### Download the latest release

  Click here to get the latest release

#### Use easy_install

  easy_install geraldo

#### Subversion latest release repository

  svn co https://geraldo.svn.sourceforge.net/svnroot/geraldo/

#### GitHub trunk repository

  git clone git://github.com/marinho/django-geraldo.git

### Screenshots

A simple report | Report with multiple-level groupping | Report with graphic images and shapes in landscape
Report with child bands in portrait | Report with charts generated by MatPlotLib | Report with charts generated by CairoPlot

### Documentation

- Overview
- Installation
- Tutorial 1
- Basic
- Widgets
- Graphics
- Generators

### Issues

If you have bug, suggestion, improvement or a patch to send, please open an issue. If you want to help us to improve Geraldo, you can also browse the existing issues and send your thoughts or patches.

- Open a New Issue
- Browse existing ones

Geraldo is a reports engine for Python or Django applications. It uses the power of ReportLab and PIL to generate reports with page header and footer, child bands, report begin and summary bands, agreggation and graphic elements, etc.

Geraldo is not dependent of anyone specific Python framework. You can use it in standalone desktop applications and web applications. It is platform independent and will work well in Linux, Mac or Windows in the most of available versions and editions.

Geraldo is under LGPL 3.0 (Lesser Gnu Public License) and you are free do download, copy, distribute and modify with no needs to pay nothing to nobody, since you respect the license terms.

Click here to contact us.

This site is still under construction, please keep coming back to see updates.